@@ -11,12 +11,12 @@ class FnHttpStatusError(AJsonPlPgSqlFunction):
 
     '''
     [CA.HttpStatus]: SMALLINT
-    [CA.Error]: JSONB
+    [CA.___Error___]: JSONB
     '''
     def body(self) -> str:
         return (
             f" {Arg.result} := {BFn.jsonb_build_object}("
             f"    '{CA.HttpStatus}', ({Arg.input}->>'{CA.HttpStatus}')::SMALLINT, "
-            f"    '{CA.Error}', ({Arg.input}->>'{CA.Error}')::JSONB"  
+            f"    '{CA.___Error___}', ({Arg.input}->>'{CA.___Error___}')::JSONB"  
             f"  )"
         )
\ No newline at end of file
